% This file gives an example
% of how to call the MATLAB PLS routine
% described in Abdi  H. (2010).
% Abdi, H. (2010). 
%   Partial least square regression, 
%   projection on latent structure regression,
%   PLS-Regression. 
%   Wiley Interdisciplinary Reviews: Computational Statistics, 
%   2, 97-106.
%   (paper available from www.utdallas.edu/~herve).
% The data used here come from Abdi (2010),
% they are given in Tables 1 & 2, and the figures
%   correspond to Figure 1.
% The results are given in Tables 3 to 13.
%
% This Batch file calls the following subroutines 
%  (which should be in the active matlab path):
%    PLS_jack_svds.m, 
%    (the following routines are used for plotting the results)
%    cormat.m, plotrname.m, plotxyha.m
%
% Herve Abdi February 2010
% herve@utdallas.edu
% Usual disclaimers apply: 
%   these programs are provided
%   "as is" without any guarantee 
clear
%

% The date here

% Y are the dependent variables
Y=[14 7 8
    10 7 6
    8 5 5
    2 4 7
    6 2 4];

% X are the independent variables / predictors
X=[7 7 13 7
    4 3 14 7
    10 5 12 5
    16 7 11 3
    13 3 10 3];  
[ni,nj]=size(X);nk=size(Y,2);


% nfact gives the number of factors/latent variables
% to keep for the prediction of Y and for the computation
% of B_pls
%
nfact=3;
nfact=2;
%

disp(['Data read. Going for PLS regression']);   
% Call the PLS routine
[T,P,W,Wstar,U,B,C,Bpls,Bpls_star,Xhat,...
          Yhat,Yjack,R2x,R2y,RESSy,PRESSy,Q2,r2y_random,rv_random,...
          Yhat4Press,Yhat4Ress]=PLS_jack_svds(X,Y,nfact);

disp(['PLS done. Going for the graphs']);      
% Here we create the names for the rows and columns     
%
%
%
% 
% nom_row_Data=['1' '2' '3' '4' '5']';
% nom_col_T=['t1'; 't2'; 't3' ;'t4'];
% nom_col_X=['Price    ';
%            'Sugar    ';
%            'Alcohol  ';
%            'Acidity  '];
% nom_col_Y=['Hedonic           ';
%            'Goes with meat    ';
%            'Goes with dessert '];
% Names for the Rows       
nom_row_Data(1,1)={'W1'};
nom_row_Data(2,1)={'W2'};
nom_row_Data(3,1)={'W3'};
nom_row_Data(4,1)={'W4'};
nom_row_Data(5,1)={'W5'};
% Names for Dependent Variables (Y set)
nom_col_Y(1,1)={'Hedonic'};
nom_col_Y(2,1)={'For meat'};
nom_col_Y(3,1)={'For Dessert'};
% Names for Independent Variables (X set)
nom_col_X(1,1)={'Price'};
nom_col_X(2,1)={'Sugar'};
nom_col_X(3,1)={'Alcohol'};
nom_col_X(4,1)={'Acidity'};

 


%*%%%%  Plot The graphs Here %%%%%%%%%%%%%%%%%%%%%%
%*%%%% Make a common plot of W and T %%%%%%%%%%%%%%
%*%%%% Plot the cricle of correlation %%%%%%%%%%%%


figure(1);clf
a1=1;a2=2;
plotxyha([W;T],a1,a2,['Predictors & Wines '],...
    [nom_col_X;nom_row_Data]);
axis('equal');
figure(2);clf
YR=cormat(Y,T);
plotrname(YR,a1,a2,...
    ['Y loadings( Circle of Correlation)'],...
    nom_col_Y);



disp(['All Done!']);   